@@ -1,4 +1,4 @@
-# Copyright (c) 2020, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -35,11 +35,11 @@ from requests.exceptions import RequestException
 from deployutils.apps.django.settings import SESSION_COOKIE_NAME
 
 from .. import settings
-from ..compat import get_model, http_cookies, six
+from ..compat import get_model, http_cookies, reverse, six
 from ..mixins import AppMixin, SessionDataMixin
 from ..perms import (check_permissions as base_check_permissions,
     find_rule, redirect_or_denied)
-from ..utils import JSONEncoder, get_app_model
+from ..utils import JSONEncoder, get_app_model, update_context_urls
 
 
 LOGGER = logging.getLogger(__name__)
@@ -62,7 +62,7 @@ class SessionProxyMixin(SessionDataMixin):
     login_url = None
 
     def check_permissions(self, request):
-        redirect_url, self.rule, self.session = base_check_permissions(
+        redirect_url, request.matched_rule, self.session = base_check_permissions(
             request, self.app, login_url=self.login_url)
         response = None
         if redirect_url:
@@ -77,7 +77,7 @@ class SessionProxyMixin(SessionDataMixin):
                     last_visited = last_visited.isoformat()
                 self.request.session.update({
                     'last_visited': last_visited})
-        return (response, self.rule.is_forward if self.rule else False)
+        return (response, request.matched_rule.is_forward if request.matched_rule else False)
 
     def get_context_data(self, **kwargs):
         context = super(SessionProxyMixin, self).get_context_data(**kwargs)
@@ -107,6 +107,7 @@ class SessionProxyMixin(SessionDataMixin):
     def options(self, request, *args, **kwargs):
         # With CORS the browser strips the Authentication header yet
         # it expects a 200 OK response.
+        self.session = {}
         request.matched_rule, request.matched_params = find_rule(
             request, self.app)
         if request.matched_rule and request.matched_rule.is_forward:
@@ -434,3 +435,12 @@ class AppDashboardView(AppMixin, UpdateView):
 class UserEngagementView(AppMixin, TemplateView):
 
     template_name = 'rules/engagement.html'
+
+    def get_context_data(self, **kwargs):
+        context = super(UserEngagementView, self).get_context_data(**kwargs)
+        update_context_urls(context, {
+            'rules': {
+               'user_engagement_download': reverse(
+                   'rules_user_engagement_download')
+        }})
+        return context
